Documentation
¶
Overview ¶
Package wizard provides shared interactive prompt helpers using charmbracelet/huh.
Index ¶
- func AskCheckbox(label string, options []Option) ([]string, error)
- func AskConfirm(label string, defaultVal bool) (bool, error)
- func AskInput(label, defaultVal string, validate func(string) error) (string, error)
- func AskSelect(label string, options []Option) (string, error)
- func ParseCommaSeparated(input string) []string
- func ToPascalCase(s string) string
- func TodayISO() string
- func ValidateKebabCase(input string) error
- func ValidateMinLength(min int) func(string) error
- func ValidatePort(input string) error
- type Option
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AskCheckbox ¶
AskCheckbox prompts the user to select multiple options.
func AskConfirm ¶
AskConfirm prompts the user for a yes/no confirmation.
func ParseCommaSeparated ¶
ParseCommaSeparated splits a comma-separated string, trims whitespace, and filters empty entries.
func ToPascalCase ¶
ToPascalCase converts a kebab-case or snake_case string to PascalCase.
func ValidateKebabCase ¶
ValidateKebabCase validates that input is lowercase kebab-case.
func ValidateMinLength ¶
ValidateMinLength returns a validator that checks minimum string length.
func ValidatePort ¶
ValidatePort validates that input is a valid port number (1-65535).
Types ¶
Click to show internal directories.
Click to hide internal directories.